summaryrefslogtreecommitdiff
path: root/include/svx/svdobj.hxx
diff options
context:
space:
mode:
authorNoel Grandin <noel@peralex.com>2014-09-28 07:51:19 +0200
committerNoel Grandin <noel@peralex.com>2014-09-30 11:47:41 +0200
commitc9d4a2887c13a5df244022276dd79a5bef8af0ea (patch)
treefb849270affd5fca01fa26094c89595d18c6f588 /include/svx/svdobj.hxx
parentd17d4d48b5dc3332fd03f6ef186ed2bda4665e7c (diff)
fdo#82577: Handle PolyPolygon
Put the TOOLS PolyPolygon class in the tools namespace. Avoids clash with the Windows PolyPolygon typedef. Change-Id: I811ecbb3d55ba4ce66e4555a8586f60fcd57fb66
Diffstat (limited to 'include/svx/svdobj.hxx')
-rw-r--r--include/svx/svdobj.hxx6
1 files changed, 3 insertions, 3 deletions
diff --git a/include/svx/svdobj.hxx b/include/svx/svdobj.hxx
index 3eac84f5efa5..81b176a668f5 100644
--- a/include/svx/svdobj.hxx
+++ b/include/svx/svdobj.hxx
@@ -69,7 +69,7 @@ class SfxUndoAction;
class XFillAttrSetItem;
class XLineAttrSetItem;
class SfxItemPool;
-class PolyPolygon;
+namespace tools { class PolyPolygon; }
class SfxPoolItem;
class SdrVirtObj;
class SdrDragView;
@@ -591,7 +591,7 @@ public:
virtual OUString TakeObjNamePlural() const;
// Das Xor-Polygon wird von der View zu Draggen des Objektes benoetigt.
// Alle Polygone innerhalb des PolyPolygon werden als PolyLine interpretiert.
// Moechte man ein geschlossenes Polygon, so muss man es explizit schliessen.
virtual basegfx::B2DPolyPolygon TakeXorPoly() const;
@@ -868,7 +868,7 @@ public:
// In this case it would have to:
// - set SOLID_BRUSH with the color of the given pen,
// - set NULL_PEN, and
// - generate PolyPolygon with two polygons with four supporting points each.
// In each case the return value is a SdrObject*, because it is also
// allowed to return group objects (e.g. for SdrTextObj).
// In the case of the conversion from TextObj to PathObj,
@@ -591,7 +591,7 @@ public:
virtual OUString TakeObjNamePlural() const;
// Das Xor-Polygon wird von der View zu Draggen des Objektes benoetigt.
- // Alle Polygone innerhalb des PolyPolygon werden als PolyLine interpretiert.
+ // Alle Polygone innerhalb des tools::PolyPolygon werden als PolyLine interpretiert.
// Moechte man ein geschlossenes Polygon, so muss man es explizit schliessen.
virtual basegfx::B2DPolyPolygon TakeXorPoly() const;
@@ -868,7 +868,7 @@ public:
// - set SOLID_BRUSH with the color of the given pen,
// - set NULL_PEN, and
- // - generate PolyPolygon with two polygons with four supporting points each.
+ // - generate tools::PolyPolygon with two polygons with four supporting points each.
// In each case the return value is a SdrObject*, because it is also
// allowed to return group objects (e.g. for SdrTextObj).